@@ -520,7 +520,7 @@ EOF
     assert_equal 'application/octet-stream', o.file_type('c.iso')
     assert_equal 'audio/mpeg',               o.file_type('/d/e.mp3')
     assert_equal 'text/css',                 o.file_type('/f/g/h.css')
-    assert_equal nil,                        o.file_type('i.nil')
+    assert_nil                               o.file_type('i.nil')
 
     # test using file object
     img_type = open(sd('ruby.png')) {|f| o.file_type(f)}
